@@ -26,27 +26,31 @@
 #ifndef SUMMARYWIDGET_H
 #define SUMMARYWIDGET_H
 
-#include <KontactInterface/Summary>
-#include <KViewStateMaintainer>
 #include <AkonadiCore/Item>
-class QGridLayout;
-class QItemSelectionModel;
-class QLabel;
-namespace KontactInterface {
-class Plugin;
-}
 
-namespace Akonadi {
-class ChangeRecorder;
-class ETMViewStateSaver;
-class Item;
-}
+#include <KontactInterface/Summary>
+
+#include <KViewStateMaintainer>
+
 namespace NoteShared {
 class NotesChangeRecorder;
 class NotesAkonadiTreeModel;
 }
+
+namespace Akonadi {
+class ETMViewStateSaver;
+}
+
+namespace KontactInterface {
+class Plugin;
+}
+
 class KCheckableProxyModel;
 
+class QGridLayout;
+class QItemSelectionModel;
+class QLabel;
+
 class KNotesSummaryWidget : public KontactInterface::Summary
 {
     Q_OBJECT
@@ -69,16 +73,16 @@ private:
     void displayNotes(const QModelIndex &parent, int &counter);
     void createNote(const Akonadi::Item &item, int counter);
     QPixmap mDefaultPixmap;
-    QGridLayout *mLayout;
-    KontactInterface::Plugin *mPlugin;
+    QGridLayout *mLayout = nullptr;
+    KontactInterface::Plugin *mPlugin = nullptr;
     QList<QLabel *> mLabels;
     QPixmap mPixmap;
-    NoteShared::NotesChangeRecorder *mNoteRecorder;
-    NoteShared::NotesAkonadiTreeModel *mNoteTreeModel;
-    QItemSelectionModel *mSelectionModel;
-    KCheckableProxyModel *mModelProxy;
-    KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mModelState;
-    bool mInProgress;
+    NoteShared::NotesChangeRecorder *mNoteRecorder = nullptr;
+    NoteShared::NotesAkonadiTreeModel *mNoteTreeModel = nullptr;
+    QItemSelectionModel *mSelectionModel = nullptr;
+    KCheckableProxyModel *mModelProxy = nullptr;
+    KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mModelState = nullptr;
+    bool mInProgress = false;
 };
 
 #endif
